The highest tagged major version is
v2.
package
Version:
v1.4.3-0...-f25e9a7
Opens a new window with list of versions in this module.
Published: Jul 15, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
Random = "random"
NginxWRR = "weighted_round_robin"
LVSWRR = "lvs_weighted_round_robin"
)
type Config struct {
Listen []string `toml:"listen"`
Upstream upstream `toml:"upstream"`
Other others `toml:"others"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.